@@ -35,7 +35,7 @@ def run(csv):
     elif cmd == 'e':
         extract_csv(df, csv)
 
-    print('Job Done. Good luck!')
+    print('\nJob Done. Good luck!')
 
 
 if __name__ == '__main__':
