@@ -23,7 +23,12 @@ def top_csv(df, csv):
             print('请从1或2中选择一个')
 
     row = df.shape[0]
-    print('\ncsv共有%s行' % row)
-    top_num = int(input('想要Top前多少行？：'))
+    while True:
+        print('\ncsv共有%s行' % row)
+        top_num = int(input('想要Top前多少行？：'))
+        if 0 < top_num <= row:
+            break
+        else:
+            print('\n输入错误，请输入1至%s之间的数！' % row)
     top_df = df.sort_values(col_name, ascending=assending)[:top_num]
     top_df.to_csv(csv.replace('.csv', '_top'+str(top_num)+'.csv'), index=False)
